@@ -267,7 +267,7 @@ def run_tests(sandbox_dir, packages, options):
 
         d = dict(number_tests=0,
                  number_failures=0,
-                 tests_ok=False)
+                 tests_ok=True)
 
         status_line = dispa = ''
 
@@ -302,16 +302,31 @@ def run_tests(sandbox_dir, packages, options):
         mo_e = errors.search(status_line)
         mo_f = failures.search(status_line)
 
-        if mo_e or mo_f:
-            num_errors = num_failures = 0
-            if mo_e: 
-                num_errors = int(mo_e.group(1))
-                d['number_failures'] += num_errors
-            if mo_f: 
-                num_failures = int(mo_f.group(1))
-                d['number_failures'] += num_failures
+
+        if options.support_zope28:
+            num_errors = 0
+            num_failures = 0
+            regex = re.compile('FAILED.*?errors=(\d*)', re.I|re.M|re.S)
+            for line in lines:
+                mo = regex.search(line)
+                if mo: 
+                   num_errors = int(mo.group(1))
+                   break
+
+            d['number_failures'] += num_errors
             d['tests_ok'] = (num_failures + num_errors == 0)
-            tests_failed += (num_failures + num_errors != 0)
+        else:
+
+            if mo_e or mo_f:
+                num_errors = num_failures = 0
+                if mo_e: 
+                    num_errors = int(mo_e.group(1))
+                    d['number_failures'] += num_errors
+                if mo_f: 
+                    num_failures = int(mo_f.group(1))
+                    d['number_failures'] += num_failures
+                d['tests_ok'] = (num_failures + num_errors == 0)
+                tests_failed += (num_failures + num_errors != 0)
 
         # write test specific logfile
         fn = os.path.join(options.log_dir, normalize(package) + '.txt')
