@@ -125,7 +125,7 @@ def db(results, options, tests_failed):
         TR = rows[0]
     else:
         TR = Testrunner(name=unicode(options.ident))
-        session.save(TR)
+        session.add(TR)
 
     TR = session.query(Testrunner).filter_by(name=unicode(options.ident)).one()
     TR.last_run = now
@@ -173,7 +173,7 @@ def db(results, options, tests_failed):
     # get hold of the id of the latest run
     run_id = max([run.id for run in TR.run])
     session.commit()
-    session.clear()
+    session.expunge_all()
 
     # prune runs older than 7 days
     TR = session.query(Testrunner).filter_by(name=unicode(options.ident)).one()
